# spot2cell
[![PyPI](https://img.shields.io/pypi/v/spot2cell?style=flat-square)](https://pypi.org/project/spot2cell/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/spot2cell?style=flat-square)](https://pypi.org/project/spot2cell/)
[![PyPI - License](https://img.shields.io/pypi/l/spot2cell?style=flat-square)](https://pypi.org/project/spot2cell/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/spot2cell)](https://pypistats.org/packages/spot2cell)
[![main](https://github.com/saezlab/liana-py/actions/workflows/main.yml/badge.svg)](https://github.com/schapirolabor/spot2cell/actions)

This tool assigns single-molecule detected spots to their respective cells in a tissue. It is designed to work with single-molecule FISH data technologies, but can be used with other types of data as well.

## Installation

```bash
pip install spot2cell
```

## Docker
Build Docker image from Dockerfile
```bash
docker build -t spot2cell .
```
## CLI

```bash
spot2cell --help
```
